
# THIS FILE IS GENERATED FROM wofrysrw SETUP.PY
short_version = '1.0.10'
version = '1.0.10'
full_version = '1.0.10.dev0+56e1393'
git_revision = '56e139318558ae7a883ef9c156a75ec43aa7379d'
release = False

if not release:
    version = full_version
    short_version += ".dev"
